@@ -4,6 +4,7 @@
 **Authors**: L. Mingarelli
 """
 import numpy as np
+import warnings
 
 def check_commonprob(commonprob):
     """
@@ -77,8 +78,9 @@ def _check_against_simulvals(x, simulvals):
     non_computable_entries = ~np.isin(x.round(10),
                                       np.array(list(simulvals.keys())))
     if non_computable_entries.any():
-        raise ValueError(f"simulvals provided is not computed to a sufficient resolution\n"
+        warnings.warn(f"simulvals provided is not computed to a sufficient resolution\n"
                          f"to resolve the common probabilies provided in commonprob.\n"
+                         f"\n\nINTERPOLATION IS GOING TO BE USED.\n\n"
                          f"Consider computing simulvals on a finer grid.\n"
                          f"The current resolution is on these points:\n{list(simulvals.keys())}\n"
                          f"Alternatively round the common probabilities or correlations provided\n"
